@@ -59,14 +59,9 @@ class AzureBlobStorageClient(FileSystem):
 
     name = AZURE_BLOB_FS_NAME
 
-    def __init__(self, account_name=None, account_key=None, **kwargs):
-        # options = get_config("azure")
-        options = {"account_name": account_name, "account_key": account_key}
-
-        options.update(kwargs)
-        self._options = options
-
-        self.account = account_name
+    def __init__(self, **kwargs):
+        self._options = kwargs
+        self.account = self._options.get("account_name")
         self.conn = self._create_connection()
 
     def _create_connection(self):
